@@ -1,21 +1,8 @@
 /*
-   This file is part of the KDE project
-   Copyright (C) 2007 David Faure <faure@kde.org>
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2007 David Faure <faure@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "konqframevisitor.h"
@@ -30,6 +17,9 @@ bool KonqViewCollector::visit(KonqFrame *frame)
 
 QList<KonqView *> KonqViewCollector::collect(KonqFrameBase *topLevel)
 {
+    if (!topLevel) {
+        return {};
+    }
     KonqViewCollector collector;
     topLevel->accept(&collector);
     return collector.m_views;
@@ -45,6 +35,9 @@ bool KonqLinkableViewsCollector::visit(KonqFrame *frame)
 
 QList<KonqView *> KonqLinkableViewsCollector::collect(KonqFrameBase *topLevel)
 {
+    if (!topLevel) {
+        return {};
+    }
     KonqLinkableViewsCollector collector;
     topLevel->accept(&collector);
     return collector.m_views;
@@ -61,6 +54,9 @@ bool KonqModifiedViewsCollector::visit(KonqFrame *frame)
 
 QList<KonqView *> KonqModifiedViewsCollector::collect(KonqFrameBase *topLevel)
 {
+    if (!topLevel) {
+        return {};
+    }
     KonqModifiedViewsCollector collector;
     topLevel->accept(&collector);
     return collector.m_views;
