@@ -15,6 +15,7 @@
 #include "choosepagesaveformatdlg.h"
 
 #include "libkonq_utils.h"
+#include "interfaces/browser.h"
 
 #include <QWebEngineView>
 #include <QWebEngineProfile>
@@ -125,14 +126,12 @@ void WebEnginePartDownloadManager::performDownload(QWebEngineDownloadRequest* it
         return;
     }
     bool forceNew = false;
-    //According to the documentation, QWebEngineDownloadRequest::page() can return nullptr "if the download was not triggered by content in a page"
-    if (!page && !m_pages.isEmpty()) {
-        qCDebug(WEBENGINEPART_LOG) << "downloading" << url << "in new window or tab";
-        page = m_pages.first();
-        forceNew = true;
-    } else if (!page) {
-        qCDebug(WEBENGINEPART_LOG) << "Couldn't find a part wanting to download" << url;
+    if (!page) {
         it->cancel();
+        bool res = downloadWithoutPart(url, it->mimeType());
+        if (!res) {
+            qCDebug(WEBENGINEPART_LOG) << "Couldn't find a part to download" << url;
+        }
         return;
     }
 
@@ -146,9 +145,11 @@ void WebEnginePartDownloadManager::performDownload(QWebEngineDownloadRequest* it
     DownloadObjective objective = fetchDownloadObjective(it->url(), page);
     //If the mimetype is supported and the objective is OpenInApplication, it means that, for whatever reason,
     //QtWebEngine decided it doesn't want to display the URL: most likely, this means that it should be saved
-    //(for example, because of "attachment" Content-Disposition header)
+    //(for example, because of "attachment" Content-Disposition header). To be more flexible, however, instead
+    //we ask the user how to proceed and, in any case, force opening the file in a new window or tab
     if (objective == DownloadObjective::OpenInApplication && supportedMimetypes().contains(it->mimeType())) {
-        objective = DownloadObjective::SaveOnly;
+        objective = DownloadObjective::AskUser;
+        forceNew = true;
     }
 
     it->setDownloadDirectory(tempDownloadDir().path());
@@ -161,6 +162,20 @@ void WebEnginePartDownloadManager::performDownload(QWebEngineDownloadRequest* it
     page->requestDownload(it, forceNew, objective);
 }
 
+bool WebEnginePartDownloadManager::downloadWithoutPart(const QUrl& url, const QString& mimeType)
+{
+    KonqInterfaces::Browser *browser = KonqInterfaces::Browser::browser(qApp);
+    if (!browser) {
+        return false;
+    }
+    KParts::OpenUrlArguments args;
+    args.setMimeType(mimeType);
+    BrowserArguments bargs;
+    bargs.setForcesNewWindow(true);
+    bargs.setNewTab(true);
+    return browser->openUrl(url, args, bargs);
+}
+
 QString WebEnginePartDownloadManager::generateDownloadTempFileName(const QString& suggestedName, const QString& ext)
 {
     QString baseName(suggestedName);
@@ -214,7 +229,7 @@ void WebEnginePartDownloadManager::saveHtmlPage(QWebEngineDownloadRequest* it, W
     job->start();
 }
 
-WebEngineDownloadJob::WebEngineDownloadJob(QWebEngineDownloadRequest* it, QObject* parent) : DownloaderJob(parent), m_downloadItem(it)
+WebEngineDownloadJob::WebEngineDownloadJob(QWebEngineDownloadRequest* it, QObject* parent) : DownloadJob(parent), m_downloadItem(it)
 {
     setCapabilities(KJob::Killable|KJob::Suspendable);
     connect(this, &KJob::result, this, &WebEngineDownloadJob::emitDownloadResult);
@@ -368,3 +383,24 @@ void WebEngineDownloadJob::emitDownloadResult(KJob* job)
     QUrl resultUrl = error() == 0 ? QUrl::fromLocalFile(downloadPath()) : Konq::makeErrorUrl(error(), errorText(), url());
     emit downloadResult(this, resultUrl);
 }
+
+WebEngineDownloadJob::Intent WebEngineDownloadJob::intent() const
+{
+    return m_intent;
+}
+
+void WebEngineDownloadJob::setIntent(Intent intent)
+{
+    m_intent = intent;
+}
+
+bool WebEngineDownloadJob::calledForSaveAs() const
+{
+    return m_calledForSaveAs;
+}
+
+void WebEngineDownloadJob::setCalledForSaveAs(bool saveAs)
+{
+    m_calledForSaveAs = saveAs;
+}
+
